@@ -2,6 +2,7 @@ import torchhd.functional as functional
 import torchhd.embeddings as embeddings
 import torchhd.structures as structures
 import torchhd.datasets as datasets
+import torchhd.utils as utils
 
 from torchhd.functional import (
     identity_hv,
@@ -20,6 +21,7 @@ __all__ = [
     "embeddings",
     "structures",
     "datasets",
+    "utils",
     "identity_hv",
     "random_hv",
     "level_hv",
